function [data]=readdof(filename,pathname,index)
%function uireaddof(file,path,inedx)
%This function has as input the location and name of a file plus
%the index variable which controls what columan is returned.
%This program will open and read a *.dof file. The output will
%be a N by M matrix with the data in the dof file as indicated 
%in by the index vairable.
%
%Dov G. June 1999. Ver. 1.0
%Dov G. Modified to return all data or indexed data Jan. 2001.

%clc;
if nargin==0
   [filename, pathname] = uigetfile('*.dof');
   fileopen=[pathname filename];
elseif nargin~=0
   fileopen=[pathname filename];
end   
fileopen=[pathname '\' filename '.dof'];
checkfile=exist([pathname '\' filename '.dof'],'file'); %check for file existence
if checkfile~=2
   data=nan;
   return;
end
try
	fid=fopen(fileopen,'r');
catch
   data=NaN;
   return
end   
%read file header
n_rec=fread(fid,1,'float');
pfram=fread(fid,1,'float');
freq=fread(fid,1,'float');

%read data
sixdata=fread(fid,inf,'float');
sixdata=reshape(sixdata,n_rec,pfram)';
if nargin == 3
   data=sixdata(:,index(:));
else
   data=sixdata;
end   
fclose('all');
return

%Six DOF Segment Positions.dof
%1 Left Foot X,
%2 Left Foot Y,
%3 Left Foot Z
%10 Left Shank X
%11 Left Shank Y
%12 Left Shank Z
%16 Left Thigh X
%17 Left Thigh Y
%18 Left Thigh Z
%25 Left Pelvis X
%26 Left Pelvis Y
%27 Left Pelvis Z
%34 Left Trunk X
%35 Left Trunk Y
%36 Left Trunk Z
%43 Left Arm X
%44 Left Arm Y
%45 Left Arm Z
%52 Right Foot X
%53 Right Foot Y
%54 Right Foot Z
%61 Right Shank X
%62 Right Shank Y
%63 Right Shank Z
%67 Right Thigh X
%68 Right Thigh Y
%69 Right Thigh Z
%76 Right Pelvis X
%77 Right Pelvis Y
%78 Right Pelvis Z
%85 Right Trunk X
%86 Right Trunk Y
%87 Right Trunk Z
%94 Right Arm X
%95 Right Arm Y
%96 Right Arm Z
%103 Head X
%104 Head Y
%105 Head Z
%112 Floater X
%113 Floater Y
%114 Floater Z
%118 Body CG X
%119 Body CG Y
%120 Body CG Z


%Six DOF Segment Rotations.dof
%4 Left Foot Roll
%5 Left Foot Pitch
%6 Left Foot Yaw
%13 Left Shank Roll
%14 Left Shank Pitch
%15 Left Shank Yaw
%19 Left Thigh Roll
%20 Left Thigh Pitch
%21 Left Thigh Yaw
%28 Left Pelvis Roll
%29 Left Pelvis Pitch
%30 Left Pelvis Yaw
%37 Left Trunk Roll
%38 Left Trunk Pitch
%39 Left Trunk Yaw
%46 Left Arm Roll
%47 Left Arm Pitch
%48 Left Arm Yaw
%55 Right Foot Roll
%56 Right Foot Pitch
%57 Right Foot Yaw
%64 Right Shank Roll
%65 Right Shank Pitch
%66 Right Shank Yaw
%70 Right Thigh Roll
%71 Right Thigh Pitch
%72 Right Thigh Yaw
%79 Right Pelvis Roll
%80 Right Pelvis Pitch
%81 Right Pelvis Yaw
%88 Right Trunk Roll
%89 Right Trunk Pitch
%90 Right Trunk Yaw
%97 Right Arm Roll
%98 Right Arm Pitch
%99 Right Arm Yaw
%106 Head Roll
%107 Head Pitch
%108 Head Yaw
%115 Floater Roll
%116 Floater Pitch
%117 Floater Yaw


%Six DOF Joint Positions.dof
%7 Left Ankle X
%8 Left Ankle Y
%9 Left Ankle Z
%22 Left Knee X
%23 Left Knee Y
%24 Left Knee Z
%31 Left Hip X
%32 Left Hip Y
%33 Left Hip Z
%40 Left Back X
%41 Left Back Y
%42 Left Back Z
%49 Left Shoulder X
%50 Left Shoulder Y
%51 Left Shoulder Z
%58 Right Ankle X
%59 Right Ankle Y
%60 Right Ankle Z
%73 Right Knee X
%74 Right Knee Y
%75 Right Knee Z
%82 Right Hip X
%83 Right Hip Y
%84 Right Hip Z
%91 Right Back X
%92 Right Back Y
%93 Right Back Z
%100 Right Shoulder X
%101 Right Shoulder Y
%102 Right Shoulder Z
%109 Neck X
%110 Neck Y
%111 Neck Z
