function [data]=readdof(filename,pathname,index)
%function uireaddof(file,path,inedx)
%This function has as input the location and name of a file plus
%the index variable which controls what columan is returned.
%This program will open and read a *.dof file. The output will
%be a N by M matrix with the data in the dof file as indicated 
%in by the index vairable.
%
%Dov G. June 1999. Ver. 1.0
%Dov G. Modified to return all data or indexed data Jan. 2001.

%clc;
if nargin==0
   [filename, pathname] = uigetfile('*.dof');
   fileopen=[pathname filename];
elseif nargin~=0
   fileopen=[pathname filename];
end   
fileopen=[pathname '\' filename '.dof'];
checkfile=exist([pathname '\' filename '.dof'],'file'); %check for file existence
if checkfile~=2
   data=nan;
   return;
end
try
	fid=fopen(fileopen,'r');
catch
   data=NaN;
   return
end   
%read file header
n_rec=fread(fid,1,'float');
pfram=fread(fid,1,'float');
freq=fread(fid,1,'float');

%read data
sixdata=fread(fid,inf,'float');
sixdata=reshape(sixdata,n_rec,pfram)';
if nargin == 3
   data=sixdata(:,index(:));
else
   data=sixdata;
end   
fclose('all');
return

%Six DOF Segment Positions.dof
%1 Left Foot X,
%2 Left Foot Y,
%3 Left Foot Z
%10 Left Shank X
%11 Left Shank Y
%12 Left Shank Z
%19 Left Thigh X
%20 Left Thigh Y
%21 Left Thigh Z
%28 Left Pelvis X
%29 Left Pelvis Y
%30 Left Pelvis Z
%37 Left Trunk X
%38 Left Trunk Y
%39 Left Trunk Z
%46 Left Arm X
%47 Left Arm Y
%48 Left Arm Z
%55 Right Foot X
%56 Right Foot Y
%57 Right Foot Z
%64 Right Shank X
%65 Right Shank Y
%66 Right Shank Z
%73 Right Thigh X
%74 Right Thigh Y
%75 Right Thigh Z
%82 Right Pelvis X
%83 Right Pelvis Y
%84 Right Pelvis Z
%91 Right Trunk X
%92 Right Trunk Y
%93 Right Trunk Z
%100 Right Arm X
%101 Right Arm Y
%102 Right Arm Z
%109 Head X
%110 Head Y
%111 Head Z
% Floater X
% Floater Y
% Floater Z
%118 Body CG X
%119 Body CG Y
%120 Body CG Z


%Six DOF Segment Rotations.dof
%4 Left Foot Roll
%5 Left Foot Pitch
%6 Left Foot Yaw
%13 Left Shank Roll
%14 Left Shank Pitch
%15 Left Shank Yaw
%22 Left Thigh Roll
%23 Left Thigh Pitch
%24 Left Thigh Yaw
%31 Left Pelvis Roll
%32 Left Pelvis Pitch
%33 Left Pelvis Yaw
%40 Left Trunk Roll
%41 Left Trunk Pitch
%42 Left Trunk Yaw
%49 Left Arm Roll
%50 Left Arm Pitch
%51 Left Arm Yaw
%58 Right Foot Roll
%59 Right Foot Pitch
%60 Right Foot Yaw
%67 Right Shank Roll
%68 Right Shank Pitch
%69 Right Shank Yaw
%76 Right Thigh Roll
%77 Right Thigh Pitch
%78 Right Thigh Yaw
%85 Right Pelvis Roll
%86 Right Pelvis Pitch
%87 Right Pelvis Yaw
%94 Right Trunk Roll
%95 Right Trunk Pitch
%96 Right Trunk Yaw
%103 Right Arm Roll
%104 Right Arm Pitch
%105 Right Arm Yaw
%112 Head Roll
%113 Head Pitch
%114 Head Yaw
% Floater Roll
% Floater Pitch
% Floater Yaw


%Six DOF Joint Positions.dof
%7 Left Ankle X
%8 Left Ankle Y
%9 Left Ankle Z
%16 Left Ankle X
%17 Left Ankle Y
%18 Left Ankle Z
%25 Left Knee X
%26 Left Knee Y
%27 Left Knee Z
%34 Left Hip X
%35 Left Hip Y
%36 Left Hip Z
%43 Left Back X
%44 Left Back Y
%45 Left Back Z
%52 Left Shoulder X
%53 Left Shoulder Y
%54 Left Shoulder Z
%61 Right Ankle X
%62 Right Ankle Y
%63 Right Ankle Z
%70 Right Ankle X
%71 Right Ankle Y
%72 Right Ankle Z
%79 Right Knee X
%80 Right Knee Y
%81 Right Knee Z
%88 Right Hip X
%89 Right Hip Y
%90 Right Hip Z
%97 Right Back X
%98 Right Back Y
%99 Right Back Z
%106 Right Shoulder X
%107 Right Shoulder Y
%108 Right Shoulder Z
%115 Neck X
%116 Neck Y
%117 Neck Z
